# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/ranker.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/ranker/ranker.proto',
  package='eolymp.ranker',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/ranker;ranker',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/ranker/ranker.proto\x12\reolymp.ranker\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\"F\n\x15\x43reateScoreboardInput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"/\n\x16\x43reateScoreboardOutput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x15UpdateScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12-\n\nscoreboard\x18\x02 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\x18\n\x16UpdateScoreboardOutput\"/\n\x16RebuildScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x19\n\x17RebuildScoreboardOutput\"_\n\x12\x41ssignContestInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x32\n\x07\x63ontest\x18\x02 \x01(\x0b\x32!.eolymp.ranker.Scoreboard.Contest\"\x15\n\x13\x41ssignContestOutput\"A\n\x14UnassignContestInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\"\x17\n\x15UnassignContestOutput\".\n\x15\x44\x65leteScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteScoreboardOutput\"$\n\x15LookupScoreboardInput\x12\x0b\n\x03key\x18\x01 \x01(\t\"G\n\x16LookupScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"0\n\x17\x44\x65scribeScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"I\n\x18\x44\x65scribeScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\xa7\x01\n\x14ListScoreboardsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.ranker.ListScoreboardsInput.Filter\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"P\n\x15ListScoreboardsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.ranker.Scoreboard\"0\n\x17ListScoreboardRowsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"W\n\x18ListScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row2\xe0\x0e\n\x06Ranker\x12\xad\x01\n\x10\x43reateScoreboard\x12$.eolymp.ranker.CreateScoreboardInput\x1a%.eolymp.ranker.CreateScoreboardOutput\"L\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18\"\x13/ranker/scoreboardsb\x01*\x12\xba\x01\n\x10UpdateScoreboard\x12$.eolymp.ranker.UpdateScoreboardInput\x1a%.eolymp.ranker.UpdateScoreboardOutput\"Y\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02%\x1a#/ranker/scoreboards/{scoreboard_id}\x12\xc5\x01\n\x11RebuildScoreboard\x12%.eolymp.ranker.RebuildScoreboardInput\x1a&.eolymp.ranker.RebuildScoreboardOutput\"a\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02-\"+/ranker/scoreboards/{scoreboard_id}/rebuild\x12\xba\x01\n\x10\x44\x65leteScoreboard\x12$.eolymp.ranker.DeleteScoreboardInput\x1a%.eolymp.ranker.DeleteScoreboardOutput\"Y\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02%*#/ranker/scoreboards/{scoreboard_id}\x12\xa3\x01\n\x10LookupScoreboard\x12$.eolymp.ranker.LookupScoreboardInput\x1a%.eolymp.ranker.LookupScoreboardOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02-\x12\x1f/ranker/scoreboard-lookup/{key}b\nscoreboard\x12\xcb\x01\n\x12\x44\x65scribeScoreboard\x12&.eolymp.ranker.DescribeScoreboardInput\x1a\'.eolymp.ranker.DescribeScoreboardOutput\"d\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x31\x12#/ranker/scoreboards/{scoreboard_id}b\nscoreboard\x12\xa9\x01\n\x0fListScoreboards\x12#.eolymp.ranker.ListScoreboardsInput\x1a$.eolymp.ranker.ListScoreboardsOutput\"K\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x18\x12\x13/ranker/scoreboardsb\x01*\x12\xa9\x01\n\x12ListScoreboardRows\x12&.eolymp.ranker.ListScoreboardRowsInput\x1a\'.eolymp.ranker.ListScoreboardRowsOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02-\x12(/ranker/scoreboards/{scoreboard_id}/rowsb\x01*\x12\xc7\x01\n\rAssignContest\x12!.eolymp.ranker.AssignContestInput\x1a\".eolymp.ranker.AssignContestOutput\"o\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02;\x1a\x39/ranker/scoreboards/{scoreboard_id}/contests/{contest_id}\x12\xcd\x01\n\x0fUnassignContest\x12#.eolymp.ranker.UnassignContestInput\x1a$.eolymp.ranker.UnassignContestOutput\"o\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02;*9/ranker/scoreboards/{scoreboard_id}/contests/{contest_id}B5Z3github.com/eolymp/contracts/go/eolymp/ranker;rankerb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_ranker_dot_scoreboard__pb2.DESCRIPTOR,])




_CREATESCOREBOARDINPUT = _descriptor.Descriptor(
  name='CreateScoreboardInput',
  full_name='eolymp.ranker.CreateScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.ranker.CreateScoreboardInput.scoreboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=281,
)


_CREATESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='CreateScoreboardOutput',
  full_name='eolymp.ranker.CreateScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.CreateScoreboardOutput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=330,
)


_UPDATESCOREBOARDINPUT = _descriptor.Descriptor(
  name='UpdateScoreboardInput',
  full_name='eolymp.ranker.UpdateScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.UpdateScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.ranker.UpdateScoreboardInput.scoreboard', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=425,
)


_UPDATESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='UpdateScoreboardOutput',
  full_name='eolymp.ranker.UpdateScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=451,
)


_REBUILDSCOREBOARDINPUT = _descriptor.Descriptor(
  name='RebuildScoreboardInput',
  full_name='eolymp.ranker.RebuildScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.RebuildScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=500,
)


_REBUILDSCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='RebuildScoreboardOutput',
  full_name='eolymp.ranker.RebuildScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=527,
)


_ASSIGNCONTESTINPUT = _descriptor.Descriptor(
  name='AssignContestInput',
  full_name='eolymp.ranker.AssignContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.AssignContestInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest', full_name='eolymp.ranker.AssignContestInput.contest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=624,
)


_ASSIGNCONTESTOUTPUT = _descriptor.Descriptor(
  name='AssignContestOutput',
  full_name='eolymp.ranker.AssignContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=647,
)


_UNASSIGNCONTESTINPUT = _descriptor.Descriptor(
  name='UnassignContestInput',
  full_name='eolymp.ranker.UnassignContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.UnassignContestInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.ranker.UnassignContestInput.contest_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=714,
)


_UNASSIGNCONTESTOUTPUT = _descriptor.Descriptor(
  name='UnassignContestOutput',
  full_name='eolymp.ranker.UnassignContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=716,
  serialized_end=739,
)


_DELETESCOREBOARDINPUT = _descriptor.Descriptor(
  name='DeleteScoreboardInput',
  full_name='eolymp.ranker.DeleteScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.DeleteScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=787,
)


_DELETESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='DeleteScoreboardOutput',
  full_name='eolymp.ranker.DeleteScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=789,
  serialized_end=813,
)


_LOOKUPSCOREBOARDINPUT = _descriptor.Descriptor(
  name='LookupScoreboardInput',
  full_name='eolymp.ranker.LookupScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.ranker.LookupScoreboardInput.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=815,
  serialized_end=851,
)


_LOOKUPSCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='LookupScoreboardOutput',
  full_name='eolymp.ranker.LookupScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.ranker.LookupScoreboardOutput.scoreboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=924,
)


_DESCRIBESCOREBOARDINPUT = _descriptor.Descriptor(
  name='DescribeScoreboardInput',
  full_name='eolymp.ranker.DescribeScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.DescribeScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=926,
  serialized_end=974,
)


_DESCRIBESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='DescribeScoreboardOutput',
  full_name='eolymp.ranker.DescribeScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.ranker.DescribeScoreboardOutput.scoreboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=976,
  serialized_end=1049,
)


_LISTSCOREBOARDSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.ranker.ListScoreboardsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.ranker.ListScoreboardsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1167,
  serialized_end=1219,
)

_LISTSCOREBOARDSINPUT = _descriptor.Descriptor(
  name='ListScoreboardsInput',
  full_name='eolymp.ranker.ListScoreboardsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.ranker.ListScoreboardsInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.ranker.ListScoreboardsInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.ranker.ListScoreboardsInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSCOREBOARDSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1219,
)


_LISTSCOREBOARDSOUTPUT = _descriptor.Descriptor(
  name='ListScoreboardsOutput',
  full_name='eolymp.ranker.ListScoreboardsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.ranker.ListScoreboardsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.ranker.ListScoreboardsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1221,
  serialized_end=1301,
)


_LISTSCOREBOARDROWSINPUT = _descriptor.Descriptor(
  name='ListScoreboardRowsInput',
  full_name='eolymp.ranker.ListScoreboardRowsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.ListScoreboardRowsInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1303,
  serialized_end=1351,
)


_LISTSCOREBOARDROWSOUTPUT = _descriptor.Descriptor(
  name='ListScoreboardRowsOutput',
  full_name='eolymp.ranker.ListScoreboardRowsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.ranker.ListScoreboardRowsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.ranker.ListScoreboardRowsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1353,
  serialized_end=1440,
)

_CREATESCOREBOARDINPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_UPDATESCOREBOARDINPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_ASSIGNCONTESTINPUT.fields_by_name['contest'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD_CONTEST
_LOOKUPSCOREBOARDOUTPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_DESCRIBESCOREBOARDOUTPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_LISTSCOREBOARDSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSCOREBOARDSINPUT_FILTER.containing_type = _LISTSCOREBOARDSINPUT
_LISTSCOREBOARDSINPUT.fields_by_name['filters'].message_type = _LISTSCOREBOARDSINPUT_FILTER
_LISTSCOREBOARDSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_LISTSCOREBOARDROWSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD_ROW
DESCRIPTOR.message_types_by_name['CreateScoreboardInput'] = _CREATESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['CreateScoreboardOutput'] = _CREATESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['UpdateScoreboardInput'] = _UPDATESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['UpdateScoreboardOutput'] = _UPDATESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['RebuildScoreboardInput'] = _REBUILDSCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['RebuildScoreboardOutput'] = _REBUILDSCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['AssignContestInput'] = _ASSIGNCONTESTINPUT
DESCRIPTOR.message_types_by_name['AssignContestOutput'] = _ASSIGNCONTESTOUTPUT
DESCRIPTOR.message_types_by_name['UnassignContestInput'] = _UNASSIGNCONTESTINPUT
DESCRIPTOR.message_types_by_name['UnassignContestOutput'] = _UNASSIGNCONTESTOUTPUT
DESCRIPTOR.message_types_by_name['DeleteScoreboardInput'] = _DELETESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['DeleteScoreboardOutput'] = _DELETESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['LookupScoreboardInput'] = _LOOKUPSCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['LookupScoreboardOutput'] = _LOOKUPSCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardInput'] = _DESCRIBESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardOutput'] = _DESCRIBESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['ListScoreboardsInput'] = _LISTSCOREBOARDSINPUT
DESCRIPTOR.message_types_by_name['ListScoreboardsOutput'] = _LISTSCOREBOARDSOUTPUT
DESCRIPTOR.message_types_by_name['ListScoreboardRowsInput'] = _LISTSCOREBOARDROWSINPUT
DESCRIPTOR.message_types_by_name['ListScoreboardRowsOutput'] = _LISTSCOREBOARDROWSOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateScoreboardInput = _reflection.GeneratedProtocolMessageType('CreateScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.CreateScoreboardInput)
  })
_sym_db.RegisterMessage(CreateScoreboardInput)

CreateScoreboardOutput = _reflection.GeneratedProtocolMessageType('CreateScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.CreateScoreboardOutput)
  })
_sym_db.RegisterMessage(CreateScoreboardOutput)

UpdateScoreboardInput = _reflection.GeneratedProtocolMessageType('UpdateScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.UpdateScoreboardInput)
  })
_sym_db.RegisterMessage(UpdateScoreboardInput)

UpdateScoreboardOutput = _reflection.GeneratedProtocolMessageType('UpdateScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.UpdateScoreboardOutput)
  })
_sym_db.RegisterMessage(UpdateScoreboardOutput)

RebuildScoreboardInput = _reflection.GeneratedProtocolMessageType('RebuildScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDSCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.RebuildScoreboardInput)
  })
_sym_db.RegisterMessage(RebuildScoreboardInput)

RebuildScoreboardOutput = _reflection.GeneratedProtocolMessageType('RebuildScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDSCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.RebuildScoreboardOutput)
  })
_sym_db.RegisterMessage(RebuildScoreboardOutput)

AssignContestInput = _reflection.GeneratedProtocolMessageType('AssignContestInput', (_message.Message,), {
  'DESCRIPTOR' : _ASSIGNCONTESTINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.AssignContestInput)
  })
_sym_db.RegisterMessage(AssignContestInput)

AssignContestOutput = _reflection.GeneratedProtocolMessageType('AssignContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _ASSIGNCONTESTOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.AssignContestOutput)
  })
_sym_db.RegisterMessage(AssignContestOutput)

UnassignContestInput = _reflection.GeneratedProtocolMessageType('UnassignContestInput', (_message.Message,), {
  'DESCRIPTOR' : _UNASSIGNCONTESTINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.UnassignContestInput)
  })
_sym_db.RegisterMessage(UnassignContestInput)

UnassignContestOutput = _reflection.GeneratedProtocolMessageType('UnassignContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _UNASSIGNCONTESTOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.UnassignContestOutput)
  })
_sym_db.RegisterMessage(UnassignContestOutput)

DeleteScoreboardInput = _reflection.GeneratedProtocolMessageType('DeleteScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DeleteScoreboardInput)
  })
_sym_db.RegisterMessage(DeleteScoreboardInput)

DeleteScoreboardOutput = _reflection.GeneratedProtocolMessageType('DeleteScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DeleteScoreboardOutput)
  })
_sym_db.RegisterMessage(DeleteScoreboardOutput)

LookupScoreboardInput = _reflection.GeneratedProtocolMessageType('LookupScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPSCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.LookupScoreboardInput)
  })
_sym_db.RegisterMessage(LookupScoreboardInput)

LookupScoreboardOutput = _reflection.GeneratedProtocolMessageType('LookupScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPSCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.LookupScoreboardOutput)
  })
_sym_db.RegisterMessage(LookupScoreboardOutput)

DescribeScoreboardInput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DescribeScoreboardInput)
  })
_sym_db.RegisterMessage(DescribeScoreboardInput)

DescribeScoreboardOutput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DescribeScoreboardOutput)
  })
_sym_db.RegisterMessage(DescribeScoreboardOutput)

ListScoreboardsInput = _reflection.GeneratedProtocolMessageType('ListScoreboardsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTSCOREBOARDSINPUT_FILTER,
    '__module__' : 'eolymp.ranker.ranker_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTSCOREBOARDSINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardsInput)
  })
_sym_db.RegisterMessage(ListScoreboardsInput)
_sym_db.RegisterMessage(ListScoreboardsInput.Filter)

ListScoreboardsOutput = _reflection.GeneratedProtocolMessageType('ListScoreboardsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDSOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardsOutput)
  })
_sym_db.RegisterMessage(ListScoreboardsOutput)

ListScoreboardRowsInput = _reflection.GeneratedProtocolMessageType('ListScoreboardRowsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDROWSINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardRowsInput)
  })
_sym_db.RegisterMessage(ListScoreboardRowsInput)

ListScoreboardRowsOutput = _reflection.GeneratedProtocolMessageType('ListScoreboardRowsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDROWSOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardRowsOutput)
  })
_sym_db.RegisterMessage(ListScoreboardRowsOutput)


DESCRIPTOR._options = None

_RANKER = _descriptor.ServiceDescriptor(
  name='Ranker',
  full_name='eolymp.ranker.Ranker',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1443,
  serialized_end=3331,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateScoreboard',
    full_name='eolymp.ranker.Ranker.CreateScoreboard',
    index=0,
    containing_service=None,
    input_type=_CREATESCOREBOARDINPUT,
    output_type=_CREATESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\030\"\023/ranker/scoreboardsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateScoreboard',
    full_name='eolymp.ranker.Ranker.UpdateScoreboard',
    index=1,
    containing_service=None,
    input_type=_UPDATESCOREBOARDINPUT,
    output_type=_UPDATESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002%\032#/ranker/scoreboards/{scoreboard_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RebuildScoreboard',
    full_name='eolymp.ranker.Ranker.RebuildScoreboard',
    index=2,
    containing_service=None,
    input_type=_REBUILDSCOREBOARDINPUT,
    output_type=_REBUILDSCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002-\"+/ranker/scoreboards/{scoreboard_id}/rebuild',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteScoreboard',
    full_name='eolymp.ranker.Ranker.DeleteScoreboard',
    index=3,
    containing_service=None,
    input_type=_DELETESCOREBOARDINPUT,
    output_type=_DELETESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002%*#/ranker/scoreboards/{scoreboard_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LookupScoreboard',
    full_name='eolymp.ranker.Ranker.LookupScoreboard',
    index=4,
    containing_service=None,
    input_type=_LOOKUPSCOREBOARDINPUT,
    output_type=_LOOKUPSCOREBOARDOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002-\022\037/ranker/scoreboard-lookup/{key}b\nscoreboard',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeScoreboard',
    full_name='eolymp.ranker.Ranker.DescribeScoreboard',
    index=5,
    containing_service=None,
    input_type=_DESCRIBESCOREBOARDINPUT,
    output_type=_DESCRIBESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0021\022#/ranker/scoreboards/{scoreboard_id}b\nscoreboard',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListScoreboards',
    full_name='eolymp.ranker.Ranker.ListScoreboards',
    index=6,
    containing_service=None,
    input_type=_LISTSCOREBOARDSINPUT,
    output_type=_LISTSCOREBOARDSOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\030\022\023/ranker/scoreboardsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListScoreboardRows',
    full_name='eolymp.ranker.Ranker.ListScoreboardRows',
    index=7,
    containing_service=None,
    input_type=_LISTSCOREBOARDROWSINPUT,
    output_type=_LISTSCOREBOARDROWSOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002-\022(/ranker/scoreboards/{scoreboard_id}/rowsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AssignContest',
    full_name='eolymp.ranker.Ranker.AssignContest',
    index=8,
    containing_service=None,
    input_type=_ASSIGNCONTESTINPUT,
    output_type=_ASSIGNCONTESTOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002;\0329/ranker/scoreboards/{scoreboard_id}/contests/{contest_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnassignContest',
    full_name='eolymp.ranker.Ranker.UnassignContest',
    index=9,
    containing_service=None,
    input_type=_UNASSIGNCONTESTINPUT,
    output_type=_UNASSIGNCONTESTOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002;*9/ranker/scoreboards/{scoreboard_id}/contests/{contest_id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RANKER)

DESCRIPTOR.services_by_name['Ranker'] = _RANKER

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/problem.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.judge import feedback_pb2 as eolymp_dot_judge_dot_feedback__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/problem.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/judge/problem.proto\x12\x0c\x65olymp.judge\x1a\x1b\x65olymp/judge/feedback.proto\"\x81\x04\n\x07Problem\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\x12\r\n\x05score\x18\x03 \x01(\x02\x12\x0f\n\x07\x62\x61se_id\x18\x04 \x01(\t\x12\x12\n\ncontest_id\x18\x05 \x01(\t\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18\n \x01(\x0e\x32\x1c.eolymp.judge.FeedbackPolicy\x12\x13\n\ntime_limit\x18\xc8\x01 \x01(\r\x12\x15\n\x0cmemory_limit\x18\xc9\x01 \x01(\x04\x12\x18\n\x0f\x66ile_size_limit\x18\xca\x01 \x01(\x04\x12\x15\n\x0csubmit_limit\x18\xcb\x01 \x01(\r\x1a\xa8\x01\n\tStatement\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x36\n\x06\x66ormat\x18\x05 \x01(\x0e\x32&.eolymp.judge.Problem.Statement.Format\"3\n\x06\x46ormat\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03TEX\x10\x01\x12\x0c\n\x08MARKDOWN\x10\x02\x12\x08\n\x04HTML\x10\x03\x1ah\n\x04Test\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0f\n\x07\x65xample\x18\x02 \x01(\x08\x12\x17\n\x0finput_object_id\x18\x03 \x01(\t\x12\x18\n\x10\x61nswer_object_id\x18\x04 \x01(\t\x12\r\n\x05score\x18\x05 \x01(\x02\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[eolymp_dot_judge_dot_feedback__pb2.DESCRIPTOR,])



_PROBLEM_STATEMENT_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='eolymp.judge.Problem.Statement.Format',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARKDOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTML', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=430,
  serialized_end=481,
)
_sym_db.RegisterEnumDescriptor(_PROBLEM_STATEMENT_FORMAT)


_PROBLEM_STATEMENT = _descriptor.Descriptor(
  name='Statement',
  full_name='eolymp.judge.Problem.Statement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.judge.Problem.Statement.locale', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='eolymp.judge.Problem.Statement.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='eolymp.judge.Problem.Statement.content', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='eolymp.judge.Problem.Statement.format', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROBLEM_STATEMENT_FORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=481,
)

_PROBLEM_TEST = _descriptor.Descriptor(
  name='Test',
  full_name='eolymp.judge.Problem.Test',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.judge.Problem.Test.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='example', full_name='eolymp.judge.Problem.Test.example', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_object_id', full_name='eolymp.judge.Problem.Test.input_object_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer_object_id', full_name='eolymp.judge.Problem.Test.answer_object_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Problem.Test.score', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=587,
)

_PROBLEM = _descriptor.Descriptor(
  name='Problem',
  full_name='eolymp.judge.Problem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Problem.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.judge.Problem.index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Problem.score', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_id', full_name='eolymp.judge.Problem.base_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.Problem.contest_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedback_policy', full_name='eolymp.judge.Problem.feedback_policy', index=5,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_limit', full_name='eolymp.judge.Problem.time_limit', index=6,
      number=200, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_limit', full_name='eolymp.judge.Problem.memory_limit', index=7,
      number=201, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size_limit', full_name='eolymp.judge.Problem.file_size_limit', index=8,
      number=202, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submit_limit', full_name='eolymp.judge.Problem.submit_limit', index=9,
      number=203, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PROBLEM_STATEMENT, _PROBLEM_TEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=587,
)

_PROBLEM_STATEMENT.fields_by_name['format'].enum_type = _PROBLEM_STATEMENT_FORMAT
_PROBLEM_STATEMENT.containing_type = _PROBLEM
_PROBLEM_STATEMENT_FORMAT.containing_type = _PROBLEM_STATEMENT
_PROBLEM_TEST.containing_type = _PROBLEM
_PROBLEM.fields_by_name['feedback_policy'].enum_type = eolymp_dot_judge_dot_feedback__pb2._FEEDBACKPOLICY
DESCRIPTOR.message_types_by_name['Problem'] = _PROBLEM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Problem = _reflection.GeneratedProtocolMessageType('Problem', (_message.Message,), {

  'Statement' : _reflection.GeneratedProtocolMessageType('Statement', (_message.Message,), {
    'DESCRIPTOR' : _PROBLEM_STATEMENT,
    '__module__' : 'eolymp.judge.problem_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Problem.Statement)
    })
  ,

  'Test' : _reflection.GeneratedProtocolMessageType('Test', (_message.Message,), {
    'DESCRIPTOR' : _PROBLEM_TEST,
    '__module__' : 'eolymp.judge.problem_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Problem.Test)
    })
  ,
  'DESCRIPTOR' : _PROBLEM,
  '__module__' : 'eolymp.judge.problem_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Problem)
  })
_sym_db.RegisterMessage(Problem)
_sym_db.RegisterMessage(Problem.Statement)
_sym_db.RegisterMessage(Problem.Test)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/category.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/category.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x65olymp/atlas/category.proto\x12\x0c\x65olymp.atlas\"\xd1\x01\n\x08\x43\x61tegory\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07visible\x18\n \x01(\x08\x12\r\n\x05index\x18\x0b \x01(\r\x12\x11\n\tparent_id\x18\x0c \x01(\t\x12\r\n\x05image\x18\x14 \x01(\t\x12\x38\n\x0c\x64\x65scriptions\x18\x1e \x03(\x0b\x32\".eolymp.atlas.Category.Description\x1a=\n\x0b\x44\x65scription\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\tB3Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
)




_CATEGORY_DESCRIPTION = _descriptor.Descriptor(
  name='Description',
  full_name='eolymp.atlas.Category.Description',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.atlas.Category.Description.locale', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='eolymp.atlas.Category.Description.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='eolymp.atlas.Category.Description.summary', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=255,
)

_CATEGORY = _descriptor.Descriptor(
  name='Category',
  full_name='eolymp.atlas.Category',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.atlas.Category.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visible', full_name='eolymp.atlas.Category.visible', index=1,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.atlas.Category.index', index=2,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='eolymp.atlas.Category.parent_id', index=3,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='eolymp.atlas.Category.image', index=4,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='eolymp.atlas.Category.descriptions', index=5,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CATEGORY_DESCRIPTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=255,
)

_CATEGORY_DESCRIPTION.containing_type = _CATEGORY
_CATEGORY.fields_by_name['descriptions'].message_type = _CATEGORY_DESCRIPTION
DESCRIPTOR.message_types_by_name['Category'] = _CATEGORY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Category = _reflection.GeneratedProtocolMessageType('Category', (_message.Message,), {

  'Description' : _reflection.GeneratedProtocolMessageType('Description', (_message.Message,), {
    'DESCRIPTOR' : _CATEGORY_DESCRIPTION,
    '__module__' : 'eolymp.atlas.category_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.atlas.Category.Description)
    })
  ,
  'DESCRIPTOR' : _CATEGORY,
  '__module__' : 'eolymp.atlas.category_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.Category)
  })
_sym_db.RegisterMessage(Category)
_sym_db.RegisterMessage(Category.Description)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/feedback.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/feedback.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x65olymp/judge/feedback.proto\x12\x0c\x65olymp.judge*;\n\x0e\x46\x65\x65\x64\x62\x61\x63kPolicy\x12\x0c\n\x08\x43OMPLETE\x10\x00\x12\x08\n\x04ICPC\x10\x01\x12\x11\n\rICPC_EXPANDED\x10\x02\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
)

_FEEDBACKPOLICY = _descriptor.EnumDescriptor(
  name='FeedbackPolicy',
  full_name='eolymp.judge.FeedbackPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ICPC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ICPC_EXPANDED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=45,
  serialized_end=104,
)
_sym_db.RegisterEnumDescriptor(_FEEDBACKPOLICY)

FeedbackPolicy = enum_type_wrapper.EnumTypeWrapper(_FEEDBACKPOLICY)
COMPLETE = 0
ICPC = 1
ICPC_EXPANDED = 2


DESCRIPTOR.enum_types_by_name['FeedbackPolicy'] = _FEEDBACKPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
